@@ -222,7 +222,8 @@ else:
 
 from butterfly import application
 
-http_server = tornado_systemd.SystemdHTTPServer(application, ssl_options=ssl_opts)
+http_server = tornado_systemd.SystemdHTTPServer(
+    application, ssl_options=ssl_opts)
 http_server.listen(port, address=host)
 url = "http%s://%s:%d/*" % (
     "s" if not tornado.options.options.unsecure else "", host, port)
